import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import { optionsListApi } from '/@/api/tigerapi/wms/house';

export const columns: BasicColumn[] = [
  {
    title: '储区编号',
    resizable: true,
    sorter: true,
    dataIndex: 'REGION_CODE',
  },
  {
    title: '货架名称',
    resizable: true,
    sorter: true,
    dataIndex: 'SHELF_NAME',
  },
  {
    title: '货架值',
    resizable: true,
    sorter: true,
    dataIndex: 'SHELF_CODE',
  },
  {
    title: '货架层数',
    resizable: true,
    sorter: true,
    dataIndex: 'FLOORS',
  },
  {
    title: '货架类型',
    resizable: true,
    sorter: true,
    dataIndex: 'SHELF_TYPE',
    customRender: ({ record }) => {
      const status = record.SHELF_TYPE;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '普通';
          color = '#C2C247';
          break;
        case 1:
          text = '二维码式';
          color = '#C2C247';
          break;
        case 2:
          text = '感应式';
          color = 'blue';
          break;
        case 3:
          text = '虚拟货架';
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '是否可用',
    resizable: true,
    sorter: true,
    dataIndex: 'IS_AVAILABLE',
    customRender: ({ record }) => {
      const status = record.IS_AVAILABLE;
      const enable = status === 'Y';
      const color = enable ? 'green' : 'red';
      const text = enable ? '启用' : '停用';
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: 'IP地址',
    resizable: true,
    sorter: true,
    dataIndex: 'IP',
    width: 180,
  },
  {
    title: '端口',
    resizable: true,
    sorter: true,
    dataIndex: 'PORT',
    width: 80,
  },
  {
    title: '创建时间',
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: '备注',
    resizable: true,
    sorter: true,
    dataIndex: 'REMARK',
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'REGION_CODE',
    label: '储区编号',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SHELF_NAME',
    label: '货架名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SHELF_CODE',
    label: '货架编码',
    component: 'Input',
    colProps: { span: 8 },
  },
  // {
  //   field: 'IS_CAR',
  //   label: '是否料车',
  //   component: 'Select',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     options: [
  //       {
  //         label: '是',
  //         value: 'Y',
  //         key: 'Y',
  //       },
  //       {
  //         label: '否',
  //         value: 'N',
  //         key: 'N',
  //       },
  //     ],
  //   },
  // },
  {
    field: 'SHELF_TYPE',
    component: 'ApiSelect',
    label: '货架类型',
    colProps: {
      span: 6,
    },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: 'Desc',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
    required: false,
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'REGION_CODE',
    label: '储区编号',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SHELF_NAME',
    label: '货架名称',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SHELF_CODE',
    label: '货架值',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'FLOORS',
    label: '货架层数',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'FLOOR_COUNT',
    label: '每层储位数',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'DIRECTION',
    label: '储位方向',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'RACKID',
    label: '货架ID',
    // required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'WEBHOOK_URL',
    label: '料车上报',
    // required: true,
    component: 'Input',
    colProps: { span: 16 },
  },
  {
    field: 'SHELF_TYPE',
    label: '货架/料车类型',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: '传统式',
          value: 0,
          key: 0,
        },
        {
          label: '二维码式',
          value: 1,
          key: 1,
        },
        {
          label: '感应式',
          value: 2,
          key: 2,
        },
        {
          label: '卡板栈板',
          value: 3,
          key: 3,
        },
        {
          label: '虚拟货架',
          value: 4,
          key: 4,
        },
      ],
    },
  },
  {
    field: 'IS_CAR',
    label: '是否料车',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: '是',
          value: 'Y',
          key: 'Y',
        },
        {
          label: '否',
          value: 'N',
          key: 'N',
        },
      ],
    },
  },
  {
    field: 'IS_AVAILABLE',
    label: '是否可用',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: '是',
          value: 'Y',
          key: 'Y',
        },
        {
          label: '否',
          value: 'N',
          key: 'N',
        },
      ],
    },
  },
  {
    field: 'IP',
    label: 'IP地址',
    // required: true,
    component: 'Input',
    colProps: { span: 16 },
  },
  {
    field: 'PORT',
    label: '端口',
    // required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'REMARK',
    label: '备注',
    // required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
];
